Class: Google::Cloud::NetworkServices::V1::AgentGateway::SelfManaged

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkservices/v1/agent_gateway.rb

Overview

Configuration for Self Managed deployment mode. Attach to existing Application Load Balancers or Secure Web Proxies.

Instance Attribute Summary collapse

Instance Attribute Details

#resource_uri::String

Returns Optional. A supported Google Cloud networking proxy in the Project and Location.

Returns:

  • (::String)

    Optional. A supported Google Cloud networking proxy in the Project and Location



113
114
115
116
# File 'proto_docs/google/cloud/networkservices/v1/agent_gateway.rb', line 113

class SelfManaged
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_uris::Array<::String>

Returns Optional. List of supported Google Cloud networking proxies in the Project and Location. resource_uris is mutually exclusive with resource_uri.

Returns:

  • (::Array<::String>)

    Optional. List of supported Google Cloud networking proxies in the Project and Location. resource_uris is mutually exclusive with resource_uri.



113
114
115
116
# File 'proto_docs/google/cloud/networkservices/v1/agent_gateway.rb', line 113

class SelfManaged
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end