Module: Google::Cloud::NetworkServices::V1::BodySendMode

Defined in:
proto_docs/google/cloud/networkservices/v1/dep.rb

Overview

The send mode for body processing.

Constant Summary collapse

BODY_SEND_MODE_UNSPECIFIED =

Default value. Do not use.

0
BODY_SEND_MODE_STREAMED =

Calls to the extension are executed in the streamed mode. Subsequent chunks will be sent only after the previous chunks have been processed.

The content of the body chunks is sent one way to the extension. Extension may send modified chunks back.

This is the default value if the processing mode is not specified.

1
BODY_SEND_MODE_FULL_DUPLEX_STREAMED =

Calls are executed in the full duplex mode. Subsequent chunks will be sent for processing without waiting for the response for the previous chunk or for the response for REQUEST_HEADERS event.

Extension can freely modify or chunk the body contents. If the extension doesn't send the body contents back, the next extension in the chain or the upstream will receive an empty body.

2