Class: Google::Cloud::NetworkServices::V1::DeleteAuthzExtensionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::DeleteAuthzExtensionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/dep.rb
Overview
Message for deleting a AuthzExtension resource.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the AuthzExtension resource to delete. Must
be in the format
projects/{project}/locations/{location}/authzExtensions/{authz_extension}.
1114 1115 1116 1117 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 1114 class DeleteAuthzExtensionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server can ignore the request if it has already been completed. The server guarantees that for 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server ignores the second request This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
1114 1115 1116 1117 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 1114 class DeleteAuthzExtensionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |