Class: Google::Cloud::NetworkServices::V1::LbRouteExtension
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::LbRouteExtension
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/dep.rb
Overview
LbRouteExtension is a resource that lets you control where traffic is
routed to for a given request.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#extension_chains ⇒ ::Array<::Google::Cloud::NetworkServices::V1::ExtensionChain>
Required.
-
#forwarding_rules ⇒ ::Array<::String>
Required.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#load_balancing_scheme ⇒ ::Google::Cloud::NetworkServices::V1::LoadBalancingScheme
Required.
-
#metadata ⇒ ::Google::Protobuf::Struct
Optional.
-
#name ⇒ ::String
Required.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was created.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 525 class LbRouteExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns Optional. A human-readable description of the resource.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 525 class LbRouteExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#extension_chains ⇒ ::Array<::Google::Cloud::NetworkServices::V1::ExtensionChain>
Returns Required. A set of ordered extension chains that contain the match conditions and extensions to execute. Match conditions for each extension chain are evaluated in sequence for a given request. The first extension chain that has a condition that matches the request is executed. Any subsequent extension chains do not execute. Limited to 5 extension chains per resource.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 525 class LbRouteExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#forwarding_rules ⇒ ::Array<::String>
Returns Required. A list of references to the forwarding rules to which this
service extension is attached. At least one forwarding rule is required.
Only one LbRouteExtension resource can be associated with a forwarding
rule.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 525 class LbRouteExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Set of labels associated with the LbRouteExtension resource.
The format must comply with the requirements for labels for Google Cloud resources.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 525 class LbRouteExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#load_balancing_scheme ⇒ ::Google::Cloud::NetworkServices::V1::LoadBalancingScheme
Returns Required. All backend services and forwarding rules referenced by this
extension must share the same load balancing scheme. Supported values:
INTERNAL_MANAGED, EXTERNAL_MANAGED. For more information, refer to
Backend services
overview.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 525 class LbRouteExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#metadata ⇒ ::Google::Protobuf::Struct
Returns Optional. The metadata provided here is included as part of the
metadata_context (of type google.protobuf.Struct) in the
ProcessingRequest message sent to the extension server.
The metadata applies to all extensions in all extensions chains in this resource.
The metadata is available under the key
com.google.lb_route_extension.<resource_name>.
The following variables are supported in the metadata:
{forwarding_rule_id} - substituted with the forwarding rule's fully
qualified resource name.
This field must not be set if at least one of the extension chains contains plugin extensions. Setting it results in a validation error.
You can set metadata at either the resource level or the extension level. The extension level metadata is recommended because you can pass a different set of metadata through each extension to the backend.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 525 class LbRouteExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. Identifier. Name of the LbRouteExtension resource in the
following format:
projects/{project}/locations/{location}/lbRouteExtensions/{lb_route_extension}.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 525 class LbRouteExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was updated.
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 525 class LbRouteExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |