Class: Google::Cloud::NetworkServices::V1::ListLbEdgeExtensionsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkservices/v1/dep.rb

Overview

Message for response to listing LbEdgeExtension resources.

Instance Attribute Summary collapse

Instance Attribute Details

#lb_edge_extensions::Array<::Google::Cloud::NetworkServices::V1::LbEdgeExtension>

Returns The list of LbEdgeExtension resources.

Returns:



707
708
709
710
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 707

class ListLbEdgeExtensionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token identifying a page of results that the server returns.

Returns:

  • (::String)

    A token identifying a page of results that the server returns.



707
708
709
710
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 707

class ListLbEdgeExtensionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Locations that could not be reached.



707
708
709
710
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 707

class ListLbEdgeExtensionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end