Class: Google::Cloud::NetworkServices::V1::TlsRoute::RouteAction
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::TlsRoute::RouteAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/tls_route.rb
Overview
The specifications for routing traffic and applying associated policies.
Instance Attribute Summary collapse
-
#destinations ⇒ ::Array<::Google::Cloud::NetworkServices::V1::TlsRoute::RouteDestination>
Required.
-
#idle_timeout ⇒ ::Google::Protobuf::Duration
Optional.
Instance Attribute Details
#destinations ⇒ ::Array<::Google::Cloud::NetworkServices::V1::TlsRoute::RouteDestination>
Returns Required. The destination services to which traffic should be forwarded. At least one destination service is required.
129 130 131 132 |
# File 'proto_docs/google/cloud/networkservices/v1/tls_route.rb', line 129 class RouteAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#idle_timeout ⇒ ::Google::Protobuf::Duration
Returns Optional. Specifies the idle timeout for the selected route. The idle timeout is defined as the period in which there are no bytes sent or received on either the upstream or downstream connection. If not set, the default idle timeout is 1 hour. If set to 0s, the timeout will be disabled.
129 130 131 132 |
# File 'proto_docs/google/cloud/networkservices/v1/tls_route.rb', line 129 class RouteAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |