Class: Google::Cloud::NetworkServices::V1::UpdateAgentGatewayRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::UpdateAgentGatewayRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/agent_gateway.rb
Overview
Request used by the UpdateAgentGateway method.
Instance Attribute Summary collapse
-
#agent_gateway ⇒ ::Google::Cloud::NetworkServices::V1::AgentGateway
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#agent_gateway ⇒ ::Google::Cloud::NetworkServices::V1::AgentGateway
Returns Required. Updated AgentGateway resource.
282 283 284 285 |
# File 'proto_docs/google/cloud/networkservices/v1/agent_gateway.rb', line 282 class UpdateAgentGatewayRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to specify the fields to be overwritten in the AgentGateway resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
282 283 284 285 |
# File 'proto_docs/google/cloud/networkservices/v1/agent_gateway.rb', line 282 class UpdateAgentGatewayRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |