Class: Google::Cloud::NetworkServices::V1::WasmPlugin::LogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::WasmPlugin::LogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/extensibility.rb
Overview
Specifies the logging options for the activity performed by this plugin. If logging is enabled, plugin logs are exported to Cloud Logging.
Defined Under Namespace
Modules: LogLevel
Instance Attribute Summary collapse
-
#enable ⇒ ::Boolean
Optional.
-
#min_log_level ⇒ ::Google::Cloud::NetworkServices::V1::WasmPlugin::LogConfig::LogLevel
Non-empty default.
-
#sample_rate ⇒ ::Float
Non-empty default.
Instance Attribute Details
#enable ⇒ ::Boolean
Returns Optional. Specifies whether to enable logging for activity by this plugin.
Defaults to false.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 211 class LogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible values to specify the lowest level of logs to be exported to # Cloud Logging. module LogLevel # Unspecified value. Defaults to `LogLevel.INFO`. LOG_LEVEL_UNSPECIFIED = 0 # Report logs with TRACE level and above. TRACE = 1 # Report logs with DEBUG level and above. DEBUG = 2 # Report logs with INFO level and above. INFO = 3 # Report logs with WARN level and above. WARN = 4 # Report logs with ERROR level and above. ERROR = 5 # Report logs with CRITICAL level only. CRITICAL = 6 end end |
#min_log_level ⇒ ::Google::Cloud::NetworkServices::V1::WasmPlugin::LogConfig::LogLevel
Returns Non-empty default. Specifies the lowest level of the plugin logs that are exported to Cloud Logging. This setting relates to the logs generated by using logging statements in your Wasm code.
This field is can be set only if logging is enabled for the plugin.
If the field is not provided when logging is enabled, it is set to
INFO by default.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 211 class LogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible values to specify the lowest level of logs to be exported to # Cloud Logging. module LogLevel # Unspecified value. Defaults to `LogLevel.INFO`. LOG_LEVEL_UNSPECIFIED = 0 # Report logs with TRACE level and above. TRACE = 1 # Report logs with DEBUG level and above. DEBUG = 2 # Report logs with INFO level and above. INFO = 3 # Report logs with WARN level and above. WARN = 4 # Report logs with ERROR level and above. ERROR = 5 # Report logs with CRITICAL level only. CRITICAL = 6 end end |
#sample_rate ⇒ ::Float
Returns Non-empty default. Configures the sampling rate of activity logs, where
1.0 means all logged activity is reported and 0.0 means no activity
is reported. A floating point value between 0.0 and 1.0 indicates
that a percentage of log messages is stored.
The default value when logging is enabled is 1.0. The value of the
field must be between 0 and 1 (inclusive).
This field can be specified only if logging is enabled for this plugin.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 211 class LogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible values to specify the lowest level of logs to be exported to # Cloud Logging. module LogLevel # Unspecified value. Defaults to `LogLevel.INFO`. LOG_LEVEL_UNSPECIFIED = 0 # Report logs with TRACE level and above. TRACE = 1 # Report logs with DEBUG level and above. DEBUG = 2 # Report logs with INFO level and above. INFO = 3 # Report logs with WARN level and above. WARN = 4 # Report logs with ERROR level and above. ERROR = 5 # Report logs with CRITICAL level only. CRITICAL = 6 end end |