Class: Google::Cloud::NetworkServices::V1::WasmPlugin::VersionDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkservices/v1/extensibility.rb

Overview

Details of a WasmPluginVersion resource to be inlined in the WasmPlugin resource.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was created.

Returns:



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 167

class VersionDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns Optional. A human-readable description of the resource.

Returns:

  • (::String)

    Optional. A human-readable description of the resource.



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 167

class VersionDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#image_digest::String (readonly)

Returns Output only. This field holds the digest (usually checksum) value for the plugin image. The value is calculated based on the image_uri field. If the image_uri field refers to a container image, the digest value is obtained from the container image. If the image_uri field refers to a generic artifact, the digest value is calculated based on the contents of the file.

Returns:

  • (::String)

    Output only. This field holds the digest (usually checksum) value for the plugin image. The value is calculated based on the image_uri field. If the image_uri field refers to a container image, the digest value is obtained from the container image. If the image_uri field refers to a generic artifact, the digest value is calculated based on the contents of the file.



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 167

class VersionDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#image_uri::String

Returns Optional. URI of the image containing the Wasm module, stored in Artifact Registry.

The URI can refer to one of the following repository formats:

  • Container images: the image_uri must point to a container that contains a single file with the name plugin.wasm. When a new WasmPluginVersion resource is created, the digest of the image is saved in the image_digest field. When pulling a container image from Artifact Registry, the digest value is used instead of an image tag.

  • Generic artifacts: the image_uri must be in this format: projects/{project}/locations/{location}/repositories/{repository}/ genericArtifacts/\\{package}:\\{version}. The specified package and version must contain a file with the name plugin.wasm. When a new WasmPluginVersion resource is created, the checksum of the contents of the file is saved in the image_digest field.

Returns:

  • (::String)

    Optional. URI of the image containing the Wasm module, stored in Artifact Registry.

    The URI can refer to one of the following repository formats:

    • Container images: the image_uri must point to a container that contains a single file with the name plugin.wasm. When a new WasmPluginVersion resource is created, the digest of the image is saved in the image_digest field. When pulling a container image from Artifact Registry, the digest value is used instead of an image tag.

    • Generic artifacts: the image_uri must be in this format: projects/{project}/locations/{location}/repositories/{repository}/ genericArtifacts/\\{package}:\\{version}. The specified package and version must contain a file with the name plugin.wasm. When a new WasmPluginVersion resource is created, the checksum of the contents of the file is saved in the image_digest field.



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 167

class VersionDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Set of labels associated with the WasmPluginVersion resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Set of labels associated with the WasmPluginVersion resource.



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 167

class VersionDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#plugin_config_data::String

Returns Configuration for the plugin. The configuration is provided to the plugin at runtime through the ON_CONFIGURE callback. When a new WasmPluginVersion version is created, the digest of the contents is saved in the plugin_config_digest field.

Note: The following fields are mutually exclusive: plugin_config_data, plugin_config_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Configuration for the plugin. The configuration is provided to the plugin at runtime through the ON_CONFIGURE callback. When a new WasmPluginVersion version is created, the digest of the contents is saved in the plugin_config_digest field.

    Note: The following fields are mutually exclusive: plugin_config_data, plugin_config_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 167

class VersionDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#plugin_config_digest::String (readonly)

Returns Output only. This field holds the digest (usually checksum) value for the plugin configuration. The value is calculated based on the contents of plugin_config_data field or the image defined by the plugin_config_uri field.

Returns:

  • (::String)

    Output only. This field holds the digest (usually checksum) value for the plugin configuration. The value is calculated based on the contents of plugin_config_data field or the image defined by the plugin_config_uri field.



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 167

class VersionDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#plugin_config_uri::String

Returns URI of the plugin configuration stored in the Artifact Registry. The configuration is provided to the plugin at runtime through the ON_CONFIGURE callback.

The URI can refer to one of the following repository formats:

  • Container images: the plugin_config_uri must point to a container that contains a single file with the name plugin.config. When a new WasmPluginVersion resource is created, the digest of the image is saved in the plugin_config_digest field. When pulling a container image from Artifact Registry, the digest value is used instead of an image tag.

  • Generic artifacts: the plugin_config_uri must be in this format: projects/{project}/locations/{location}/repositories/{repository}/ genericArtifacts/\\{package}:\\{version}. The specified package and version must contain a file with the name plugin.config. When a new WasmPluginVersion resource is created, the checksum of the contents of the file is saved in the plugin_config_digest field.

Note: The following fields are mutually exclusive: plugin_config_uri, plugin_config_data. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    URI of the plugin configuration stored in the Artifact Registry. The configuration is provided to the plugin at runtime through the ON_CONFIGURE callback.

    The URI can refer to one of the following repository formats:

    • Container images: the plugin_config_uri must point to a container that contains a single file with the name plugin.config. When a new WasmPluginVersion resource is created, the digest of the image is saved in the plugin_config_digest field. When pulling a container image from Artifact Registry, the digest value is used instead of an image tag.

    • Generic artifacts: the plugin_config_uri must be in this format: projects/{project}/locations/{location}/repositories/{repository}/ genericArtifacts/\\{package}:\\{version}. The specified package and version must contain a file with the name plugin.config. When a new WasmPluginVersion resource is created, the checksum of the contents of the file is saved in the plugin_config_digest field.

    Note: The following fields are mutually exclusive: plugin_config_uri, plugin_config_data. If a field in that set is populated, all other fields in the set will automatically be cleared.



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 167

class VersionDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was updated.

Returns:



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/networkservices/v1/extensibility.rb', line 167

class VersionDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end