Class: Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/agent_gateway.rb
Overview
NetworkConfig contains network configurations for the AgentGateway.
Defined Under Namespace
Classes: DnsPeeringConfig, Egress
Instance Attribute Summary collapse
-
#dns_peering_config ⇒ ::Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::DnsPeeringConfig
Optional.
-
#egress ⇒ ::Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::Egress
Optional.
Instance Attribute Details
#dns_peering_config ⇒ ::Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::DnsPeeringConfig
Returns Optional. Optional DNS peering configuration for connectivity to your private VPC network.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'proto_docs/google/cloud/networkservices/v1/agent_gateway.rb', line 122 class NetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for Egress # @!attribute [rw] network_attachment # @return [::String] # Optional. The URI of the Network Attachment resource. # @!attribute [rw] trust_config # @return [::Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::Egress::TrustConfig] # Optional. TrustConfig defines the trust configuration for egress. class Egress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # TrustConfig defines the trust configuration for egress. # @!attribute [rw] pem_certificates # @return [::Array<::String>] # Required. PEM encoded root certificates used to validate the identity # of the upstream servers/destinations during egress connections. class TrustConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # DNS peering config for the user VPC network. # @!attribute [rw] domains # @return [::Array<::String>] # Required. Domain names for which DNS queries should be forwarded to the # target network. # @!attribute [rw] target_project # @return [::String] # Required. Target project ID to which DNS queries should be forwarded # to. This can be the same project that contains the AgentGateway or a # different project. # @!attribute [rw] target_network # @return [::String] # Required. Target network in 'target project' to which DNS queries # should be forwarded to. Must be in format of # `projects/{project}/global/networks/{network}`. class DnsPeeringConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#egress ⇒ ::Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::Egress
Returns Optional. Optional PSC-Interface network attachment for connectivity to your private VPCs network.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'proto_docs/google/cloud/networkservices/v1/agent_gateway.rb', line 122 class NetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for Egress # @!attribute [rw] network_attachment # @return [::String] # Optional. The URI of the Network Attachment resource. # @!attribute [rw] trust_config # @return [::Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::Egress::TrustConfig] # Optional. TrustConfig defines the trust configuration for egress. class Egress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # TrustConfig defines the trust configuration for egress. # @!attribute [rw] pem_certificates # @return [::Array<::String>] # Required. PEM encoded root certificates used to validate the identity # of the upstream servers/destinations during egress connections. class TrustConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # DNS peering config for the user VPC network. # @!attribute [rw] domains # @return [::Array<::String>] # Required. Domain names for which DNS queries should be forwarded to the # target network. # @!attribute [rw] target_project # @return [::String] # Required. Target project ID to which DNS queries should be forwarded # to. This can be the same project that contains the AgentGateway or a # different project. # @!attribute [rw] target_network # @return [::String] # Required. Target network in 'target project' to which DNS queries # should be forwarded to. Must be in format of # `projects/{project}/global/networks/{network}`. class DnsPeeringConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |