Class: Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::Egress
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::Egress
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/agent_gateway.rb
Overview
Configuration for Egress
Defined Under Namespace
Classes: TrustConfig
Instance Attribute Summary collapse
-
#network_attachment ⇒ ::String
Optional.
-
#trust_config ⇒ ::Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::Egress::TrustConfig
Optional.
Instance Attribute Details
#network_attachment ⇒ ::String
Returns Optional. The URI of the Network Attachment resource.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'proto_docs/google/cloud/networkservices/v1/agent_gateway.rb', line 133 class Egress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # TrustConfig defines the trust configuration for egress. # @!attribute [rw] pem_certificates # @return [::Array<::String>] # Required. PEM encoded root certificates used to validate the identity # of the upstream servers/destinations during egress connections. class TrustConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#trust_config ⇒ ::Google::Cloud::NetworkServices::V1::AgentGateway::NetworkConfig::Egress::TrustConfig
Returns Optional. TrustConfig defines the trust configuration for egress.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'proto_docs/google/cloud/networkservices/v1/agent_gateway.rb', line 133 class Egress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # TrustConfig defines the trust configuration for egress. # @!attribute [rw] pem_certificates # @return [::Array<::String>] # Required. PEM encoded root certificates used to validate the identity # of the upstream servers/destinations during egress connections. class TrustConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |