Class: Google::Cloud::NetworkServices::V1::AgentGateway::SelfManaged
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::AgentGateway::SelfManaged
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/agent_gateway.rb
Overview
Configuration for Self Managed deployment mode. Attach to existing Application Load Balancers or Secure Web Proxies.
Instance Attribute Summary collapse
-
#resource_uri ⇒ ::String
Optional.
Instance Attribute Details
#resource_uri ⇒ ::String
Returns Optional. A supported Google Cloud networking proxy in the Project and Location.
108 109 110 111 |
# File 'proto_docs/google/cloud/networkservices/v1/agent_gateway.rb', line 108 class SelfManaged include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |