Class: Google::Cloud::NetworkServices::V1::CreateLbEdgeExtensionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkservices/v1/dep.rb

Overview

Message for creating a LbEdgeExtension resource.

Instance Attribute Summary collapse

Instance Attribute Details

#lb_edge_extension::Google::Cloud::NetworkServices::V1::LbEdgeExtension

Returns Required. LbEdgeExtension resource to be created.

Returns:



748
749
750
751
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 748

class CreateLbEdgeExtensionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#lb_edge_extension_id::String

Returns Required. User-provided ID of the LbEdgeExtension resource to be created.

Returns:

  • (::String)

    Required. User-provided ID of the LbEdgeExtension resource to be created.



748
749
750
751
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 748

class CreateLbEdgeExtensionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource of the LbEdgeExtension resource. Must be in the format projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource of the LbEdgeExtension resource. Must be in the format projects/{project}/locations/{location}.



748
749
750
751
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 748

class CreateLbEdgeExtensionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server can ignore the request if it has already been completed. The server guarantees that for 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server ignores the second request This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server can ignore the request if it has already been completed. The server guarantees that for 60 minutes since the first request.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server ignores the second request This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



748
749
750
751
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 748

class CreateLbEdgeExtensionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end