Class: Google::Cloud::NetworkServices::V1::ExtensionChain::Extension
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::ExtensionChain::Extension
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/dep.rb
Overview
A single extension in the chain to execute for the matching request.
Instance Attribute Summary collapse
-
#authority ⇒ ::String
Optional.
-
#fail_open ⇒ ::Boolean
Optional.
-
#forward_attributes ⇒ ::Array<::String>
Optional.
-
#forward_headers ⇒ ::Array<::String>
Optional.
-
#metadata ⇒ ::Google::Protobuf::Struct
Optional.
-
#name ⇒ ::String
Optional.
-
#observability_mode ⇒ ::Boolean
Optional.
-
#request_body_send_mode ⇒ ::Google::Cloud::NetworkServices::V1::BodySendMode
Optional.
-
#response_body_send_mode ⇒ ::Google::Cloud::NetworkServices::V1::BodySendMode
Optional.
-
#service ⇒ ::String
Required.
-
#supported_events ⇒ ::Array<::Google::Cloud::NetworkServices::V1::EventType>
Optional.
-
#timeout ⇒ ::Google::Protobuf::Duration
Optional.
Instance Attribute Details
#authority ⇒ ::String
Returns Optional. The :authority header in the gRPC request sent from Envoy
to the extension service.
Required for Callout extensions.
This field is not supported for plugin extensions. Setting it results in a validation error.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fail_open ⇒ ::Boolean
Returns Optional. Determines how the proxy behaves if the call to the extension fails or times out.
When set to TRUE, request or response processing continues without
error. Any subsequent extensions in the extension chain are also
executed. When set to FALSE or the default setting of FALSE is used,
one of the following happens:
If response headers have not been delivered to the downstream client, a generic 500 error is returned to the client. The error response can be tailored by configuring a custom error response in the load balancer.
If response headers have been delivered, then the HTTP stream to the downstream client is reset.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#forward_attributes ⇒ ::Array<::String>
Returns Optional. List of the Envoy attributes to forward to the extension
server. The attributes provided here are included as part of the
ProcessingRequest.attributes field (of type
map<string, google.protobuf.Struct>), where the keys are the attribute
names. Refer to the
documentation
for the names of attributes that can be forwarded. If omitted, no
attributes are sent. Each element is a string indicating the
attribute name.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#forward_headers ⇒ ::Array<::String>
Returns Optional. List of the HTTP headers to forward to the extension (from the client or backend). If omitted, all headers are sent. Each element is a string indicating the header name.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metadata ⇒ ::Google::Protobuf::Struct
Returns Optional. The metadata provided here is included as part of the
metadata_context (of type google.protobuf.Struct) in the
ProcessingRequest message sent to the extension server.
For AuthzExtension resources, the metadata is available under the
namespace com.google.authz_extension.<resource_name>.
For other types of extensions, the metadata is available under the
namespace
com.google.<extension_type>.<resource_name>.<extension_chain_name>.<extension_name>.
For example:
com.google.lb_traffic_extension.lbtrafficextension1.chain1.ext1.
The following variables are supported in the metadata:
{forwarding_rule_id} - substituted with the forwarding rule's fully
qualified resource name.
This field must not be set for plugin extensions. Setting it results in a validation error.
You can set metadata at either the resource level or the extension level. The extension level metadata is recommended because you can pass a different set of metadata through each extension to the backend.
This field is subject to following limitations:
- The total size of the metadata must be less than 1KiB.
- The total number of keys in the metadata must be less than 16.
- The length of each key must be less than 64 characters.
- The length of each value must be less than 1024 characters.
- All values must be strings.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Optional. The name for this extension. The name is logged as part of the HTTP request logs. The name must conform with RFC-1034, is restricted to lower-cased letters, numbers and hyphens, and can have a maximum length of 63 characters. Additionally, the first character must be a letter and the last a letter or a number.
This field is required except for AuthzExtension.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#observability_mode ⇒ ::Boolean
Returns Optional. When set to true, the calls to the extension backend are
performed asynchronously, without pausing the processing of the ongoing
request. In this mode, only STREAMED (default) body processing is
supported. Responses, if any, are ignored.
Supported by regional LbTrafficExtension and LbRouteExtension
resources.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_body_send_mode ⇒ ::Google::Cloud::NetworkServices::V1::BodySendMode
Returns Optional. Configures the send mode for request body processing.
The field can only be set if supported_events includes REQUEST_BODY.
If supported_events includes REQUEST_BODY,
but request_body_send_mode is unset, the default value STREAMED is
used.
When this field is set to FULL_DUPLEX_STREAMED, supported_events
must include both REQUEST_BODY and REQUEST_TRAILERS.
This field can be set only for LbTrafficExtension and
LbRouteExtension resources, and only when the service field of the
extension points to a BackendService. Only FULL_DUPLEX_STREAMED mode
is supported for LbRouteExtension resources.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#response_body_send_mode ⇒ ::Google::Cloud::NetworkServices::V1::BodySendMode
Returns Optional. Configures the send mode for response processing. If
unspecified, the default value STREAMED is used.
The field can only be set if supported_events includes RESPONSE_BODY.
If supported_events includes RESPONSE_BODY, but
response_body_send_mode is unset, the default value STREAMED is used.
When this field is set to FULL_DUPLEX_STREAMED, supported_events
must include both RESPONSE_BODY and RESPONSE_TRAILERS.
This field can be set only for LbTrafficExtension resources, and only
when the service field of the extension points to a BackendService.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service ⇒ ::String
Returns Required. The reference to the service that runs the extension.
To configure a callout extension, service must be a fully-qualified
reference
to a backend
service
in the format:
https://www.googleapis.com/compute/v1/projects/{project}/regions/{region}/backendServices/{backendService}
or
https://www.googleapis.com/compute/v1/projects/{project}/global/backendServices/{backendService}.
To configure a plugin extension, service must be a reference
to a WasmPlugin
resource
in the format:
projects/{project}/locations/{location}/wasmPlugins/{plugin}
or
//networkservices.googleapis.com/projects/{project}/locations/{location}/wasmPlugins/{wasmPlugin}.
Plugin extensions are currently supported for the
LbTrafficExtension, the LbRouteExtension, and the LbEdgeExtension
resources.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#supported_events ⇒ ::Array<::Google::Cloud::NetworkServices::V1::EventType>
Returns Optional. A set of events during request or response processing for which this extension is called.
For the LbTrafficExtension resource, this field is required.
For the LbRouteExtension resource, this field is optional. If
unspecified, REQUEST_HEADERS event is assumed as supported.
For the LbEdgeExtension resource, this field is required and must only
contain REQUEST_HEADERS event.
For the AuthzExtension resource, this field is optional.
REQUEST_HEADERS is the only supported event. If unspecified,
REQUEST_HEADERS event is assumed as supported.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#timeout ⇒ ::Google::Protobuf::Duration
Returns Optional. Specifies the timeout for each individual message on the
stream. The timeout must be between 10-10000 milliseconds. Required
for callout extensions.
This field is not supported for plugin extensions. Setting it results in a validation error.
233 234 235 236 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 233 class Extension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |