Class: Google::Cloud::NetworkServices::V1::LbEdgeExtension
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::LbEdgeExtension
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/dep.rb
Overview
LbEdgeExtension is a resource that lets the extension service influence
the selection of backend services and Cloud CDN cache keys by modifying
request headers.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#extension_chains ⇒ ::Array<::Google::Cloud::NetworkServices::V1::ExtensionChain>
Required.
-
#forwarding_rules ⇒ ::Array<::String>
Required.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#load_balancing_scheme ⇒ ::Google::Cloud::NetworkServices::V1::LoadBalancingScheme
Required.
-
#name ⇒ ::String
Required.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was created.
659 660 661 662 663 664 665 666 667 668 669 670 671 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 659 class LbEdgeExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns Optional. A human-readable description of the resource.
659 660 661 662 663 664 665 666 667 668 669 670 671 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 659 class LbEdgeExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#extension_chains ⇒ ::Array<::Google::Cloud::NetworkServices::V1::ExtensionChain>
Returns Required. A set of ordered extension chains that contain the match conditions and extensions to execute. Match conditions for each extension chain are evaluated in sequence for a given request. The first extension chain that has a condition that matches the request is executed. Any subsequent extension chains do not execute. Limited to 5 extension chains per resource.
659 660 661 662 663 664 665 666 667 668 669 670 671 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 659 class LbEdgeExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#forwarding_rules ⇒ ::Array<::String>
Returns Required. A list of references to the forwarding rules to which this
service extension is attached. At least one forwarding rule is required.
Only one LbEdgeExtension resource can be associated with a forwarding
rule.
659 660 661 662 663 664 665 666 667 668 669 670 671 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 659 class LbEdgeExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Set of labels associated with the LbEdgeExtension resource.
The format must comply with the requirements for labels for Google Cloud resources.
659 660 661 662 663 664 665 666 667 668 669 670 671 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 659 class LbEdgeExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#load_balancing_scheme ⇒ ::Google::Cloud::NetworkServices::V1::LoadBalancingScheme
Returns Required. All forwarding rules referenced by this extension must
share the same load balancing scheme.
Supported values: EXTERNAL_MANAGED.
659 660 661 662 663 664 665 666 667 668 669 670 671 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 659 class LbEdgeExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. Identifier. Name of the LbEdgeExtension resource in the
following format:
projects/{project}/locations/{location}/lbEdgeExtensions/{lb_edge_extension}.
659 660 661 662 663 664 665 666 667 668 669 670 671 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 659 class LbEdgeExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was updated.
659 660 661 662 663 664 665 666 667 668 669 670 671 |
# File 'proto_docs/google/cloud/networkservices/v1/dep.rb', line 659 class LbEdgeExtension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |