Class: Google::Cloud::NetworkServices::V1::UpdateServiceBindingRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkServices::V1::UpdateServiceBindingRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkservices/v1/service_binding.rb
Overview
Request used by the UpdateServiceBinding method.
Instance Attribute Summary collapse
-
#service_binding ⇒ ::Google::Cloud::NetworkServices::V1::ServiceBinding
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#service_binding ⇒ ::Google::Cloud::NetworkServices::V1::ServiceBinding
Returns Required. Updated ServiceBinding resource.
151 152 153 154 |
# File 'proto_docs/google/cloud/networkservices/v1/service_binding.rb', line 151 class UpdateServiceBindingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to specify the fields to be overwritten in the ServiceBinding resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
151 152 153 154 |
# File 'proto_docs/google/cloud/networkservices/v1/service_binding.rb', line 151 class UpdateServiceBindingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |